@@ -43,7 +43,7 @@ class TestApacheConfigBuilder(TestCase):
         ))
     
     def testGetAdminHostConfig(self):
-        expFrag = 'PythonHandler django.core.handlers.modpython'
+        expFrag = 'PythonHandler '
         configFrag = self.configBuilder.getAdminHostConfig()
         self.failUnlessFragInFrag(expFrag, configFrag)
 
