@@ -7,7 +7,7 @@ class AdministrationUtility(dm.cli.admin.AdministrationUtility):
 
     def buildApplication(self):
         import kforge.soleInstance
- 
+
     def do_updatefeed(self, line=None):
         args = self.convertLineToArgs(line)
         if len(args) != 0:
@@ -40,7 +40,8 @@ class AdministrationUtility(dm.cli.admin.AdministrationUtility):
         application.registry.feedentries.truncate()
         print "Feed summary now:"
         for e in application.registry.feedentries.listSummary():
-            print e.updated, e.source, e.title
+            msg = u"%s %s %s" % e.updated, e.source, e.title
+            print msg.encode('utf-8')
 
     def help_updatefeed(self, line=None):
         usage = \
@@ -49,41 +50,9 @@ class AdministrationUtility(dm.cli.admin.AdministrationUtility):
 Update feeds from site services.'''
         print usage
 
-    def do_fs(self, line=None):
-        args = self.convertLineToArgs(line)
-        if len(args) == 0:
-            print 'Error: Insufficient arguments\n'
-            self.help_fs(line)
-            return 1
-        elif args[0] == 'create':
-            try:
-                self.createFilesystem()
-                return 0
-            except Exception, inst:
-                print "Error: Couldn't create filesystem: %s" % str(inst)
-        else:
-            self.help_fs()
-            return 1
-
-    def createFilesystem(self):
-        import kforge.cli.data
-        installer = kforge.cli.data.InstallData()
-        installer.execute()
-
-    def help_fs(self, line=None):
-        usage = \
-'''fs create 
-
-Install template and media files to filesystem paths set in your
-KForge configuration file (see 'templates_dir' and 'media_dir').
-'''
-        print usage
-
-    def do_data(self, line=None):
-        return self.do_fs(line)
-
-    def help_data(self, line=None):
-        return self.help_fs(line)
+    def constructSystemDictionary(self):
+        from kforge.dictionary import SystemDictionary
+        return SystemDictionary()
 
     def do_plugin(self, line=None):
         args = self.convertLineToArgs(line)
