@@ -4,7 +4,7 @@ import kforge.command.initialisetest
 import kforge.command.projecttest
 import kforge.command.membertest
 import kforge.command.servicetest
-import kforge.command.misctest
+import kforge.command.emailpasswordtest
 #import kforge.command.projectwithadministratortest
 from kforge.exceptions import *
 
@@ -16,7 +16,7 @@ def suite():
         kforge.command.membertest.suite(),
         kforge.command.servicetest.suite(),
 #        kforge.command.projectwithadministratortest.suite(),
-        kforge.command.misctest.suite(),
+        kforge.command.emailpasswordtest.suite(),
     ]
     return unittest.TestSuite(suites)
 
