@@ -27,7 +27,7 @@ class AuthenticateView(KforgeView):
                 {'title': 'Log in',       'url': '/login/'},
             )
             self.minorNavigation.append(
-                {'title': 'Register',     'url': '/person/create/'},
+                {'title': 'Join',     'url': '/person/create/'},
             )
 
     def canAccess(self):
@@ -40,7 +40,6 @@ class AuthenticateView(KforgeView):
         name = params['name']
         forgotpassword = params.get('forgotpassword', False)
         if forgotpassword:
-            # TODO: might want to indicate error if mailing fails
             self.forgotPassword = True
             cmd = EmailNewPassword(name)
             try:
@@ -48,25 +47,24 @@ class AuthenticateView(KforgeView):
             except KforgeCommandError, inst:
                 msg = "EmailNewPassword failed for user: '%s' (%s)" % (name,
                         inst)
-                self.logger.warn(msg)
-            return # early out
-        password = params['password']
-        self.rememberme = params.get('rememberme', None)
-        command = kforge.command.PersonAuthenticate(name, password)
-        try:
-            command.execute()
-        except KforgeCommandError, inst:
-            msg = "Login authentication failure for person name '%s'." % name
-            self.logger.warn(msg)
+                self.logger.error(msg)
+                # Todo: Indicate error to user?
+                # Todo: Confirmation before actual change.
         else:
-            self.startSession(command.person)
-
+            password = params['password']
+            command = kforge.command.PersonAuthenticate(name, password)
+            try:
+                command.execute()
+            except KforgeCommandError, inst:
+                msg = "Login authentication failure for person name '%s'." % name
+                self.logger.warn(msg)
+            else:
+                self.startSession(command.person)
 
     def setContext(self):
         super(AuthenticateView, self).setContext()
         self.setAuthenticationContext()
         self.context.update({
-            'canCreatePerson': self.canCreatePerson(),
             'isAuthenticateFail': self.isAuthenticateFail,
             'forgotPassword': self.forgotPassword,
         })
@@ -90,6 +88,8 @@ class LoginView(AuthenticateView):
             self.authenticate()
             params = self.request.POST.copy()
             returnPath = params.get('returnPath', '')
+            if returnPath and returnPath[0] != '/':
+                returnPath = '/%s' % returnPath
             if returnPath:
                 self.returnPath = returnPath
             if self.session:
@@ -99,6 +99,9 @@ class LoginView(AuthenticateView):
                 self.isAuthenticateFail = True
         elif returnPath:
             self.returnPath = returnPath
+        elif self.request.GET:
+            params = self.request.GET.copy()
+            self.returnPath = params.get('returnPath', '')
         return self.getResponse()
 
 
@@ -109,7 +112,8 @@ class LogoutView(AuthenticateView):
 
     def logout(self, redirectPath=''):
         self.redirectPath = redirectPath
-        self.stopSession()
+        if self.session:
+            self.stopSession()
         return self.getResponse()
 
 
