@@ -13,12 +13,8 @@ class KforgeView(SessionView):
 
     def setContext(self, **kwds):
         super(KforgeView, self).setContext(**kwds)
-        # set here rather than on KforgeView
-        # if set on KforgeView get error
-        # 'thread._local' object has no attribute 'mapper'
         url_scheme = kforge.url.UrlScheme()
         self.context.update({
-            'kforgeProjectHost' : self.dictionary['domain_name'],
-            'kforge_media_url' : url_scheme.url_for_qualified('media'),
+            'kforge_media_url' : url_scheme.url_for('media'),
         })  
 
