@@ -17,9 +17,6 @@ class MemberView(ProjectHasManyView):
         super(MemberView, self).setContext()
         self.context.update({
             'member' : self.getAssociationObject(),
-            'canCreateMember': self.canCreateMember(),
-            'canUpdateMember': self.canUpdateMember(),
-            'canDeleteMember': self.canDeleteMember(),
         })
 
     def setMinorNavigationItem(self):
