@@ -1,3 +1,4 @@
+import kforge.django.apps.kui.views.test.welcome
 import kforge.django.apps.kui.views.test.manipulator
 import kforge.django.apps.kui.views.test.project
 import kforge.django.apps.kui.views.test.person
@@ -6,8 +7,14 @@ import kforge.django.apps.kui.views.test.member
 import kforge.django.apps.kui.views.test.admin
 import unittest
 
+# Just check these modules can actually be imported.
+# Todo: Do this elsewhere.
+import kforge.django.settings.urls.main  
+import kforge.django.settings.main  
+
 def suite():
     suites = [
+        kforge.django.apps.kui.views.test.welcome.suite(),
         kforge.django.apps.kui.views.test.manipulator.suite(),
         kforge.django.apps.kui.views.test.project.suite(),
         kforge.django.apps.kui.views.test.person.suite(),
