@@ -1,6 +1,6 @@
 from dm.dom.stateful import *
 
-class Member(StatefulObject):
+class Member(DatedStatefulObject):
     """
     Registers membership of a project by a person. 
     Associates a Person, a Project, and a Role.
