@@ -1,11 +1,10 @@
 from dm.dom.stateful import *
 import dm.dom.person
-import md5
 
 class Person(dm.dom.person.Person):
     "Registered person."
 
-    memberships = HasMany('Member', 'project')
+    memberships = AggregatesMany('Member', 'project')
 
     isUnique = False
 
@@ -25,5 +24,5 @@ class Person(dm.dom.person.Person):
 
     def getFirstName(self):
         name = self.getLabelValue()
-        parts = name.split(' ')
+        parts = name.strip().split(' ')
         return parts[0]
