@@ -7,6 +7,7 @@ import kforge.plugin.base
 import os
 from dm.strategy import FindProtectionObject
 from dm.strategy import CreateProtectionObject
+from dm.dictionarywords import DB_MIGRATION_IN_PROGRESS
 
 class Plugin(kforge.plugin.base.NonServicePlugin):
     "AccessControl plugin."
@@ -16,6 +17,8 @@ class Plugin(kforge.plugin.base.NonServicePlugin):
         name = 'accesscontrol'
 
     def onPersonCreate(self, person):
+        if self.dictionary[DB_MIGRATION_IN_PROGRESS]:
+            return
         createObject = CreateProtectionObject(person)
         protectionObject = createObject.create()
         for permission in protectionObject.permissions:
@@ -23,6 +26,8 @@ class Plugin(kforge.plugin.base.NonServicePlugin):
                 person.grants.create(permission)
     
     def onPersonPurge(self, person):
+        if self.dictionary[DB_MIGRATION_IN_PROGRESS]:
+            return
         findObject = FindProtectionObject(person)
         protectionObject = findObject.find()
         if protectionObject:
