@@ -20,22 +20,23 @@ class TestPlugin(TestCase):
         domainObject = type('Plugin', (), {})
         domainObject.name = 'accesscontrol'
         self.plugin = kforge.plugin.accesscontrol.Plugin(domainObject)
-        fixtureName = 'TestAccessControlPlugin'
-        if fixtureName in self.registry.persons:
-            person = self.registry.persons[fixtureName]
+        self.fixtureName = 'TestAccessControlPlugin'
+        if self.fixtureName in self.registry.persons:
+            person = self.registry.persons[self.fixtureName]
             person.delete()
             person.purge()
-        self.person = self.registry.persons.create(fixtureName)
+        self.person = self.registry.persons.create(self.fixtureName)
         for grant in self.person.grants:
             grant.delete()
 
     def tearDown(self):
         self.command = None
         self.plugin = None
-        if self.person:
-            self.person.delete()
-            self.person.purge()
-            self.person = None
+        if self.fixtureName in self.registry.persons:
+            person = self.registry.persons[self.fixtureName]
+            person.delete()
+            person.purge()
+            person = None
 
     def test_pluginSystemExists(self):
         self.failUnless(self.plugin)
