@@ -26,10 +26,14 @@ class Plugin(kforge.plugin.base.SingleServicePlugin):
     def __init__(self, domainObject):
         super(Plugin, self).__init__(domainObject)
     
+    def onServiceCreate(self, service):
+        if self.isOurs(service):
+            self.paths.assertProjectFolder(service.project)
+
     def getApacheConfig(self, service):
-        projectDirPath = self.paths.getProjectPath(service.project)
-        result = 'Alias %(urlPath)s ' + projectDirPath
-        # ForceType text/plain so that dav interprets all file types as text
+        projectPath = self.paths.getProjectPath(service.project)
+        result = 'Alias %(urlPath)s ' + projectPath
+        # 'ForceType text/plain' so DAV interprets all file types as text.
         result += """
             <Location %(urlPath)s>
                 DAV On
@@ -43,15 +47,19 @@ class Plugin(kforge.plugin.base.SingleServicePlugin):
         return result
     
     def onCreate(self):
-        """
-        Only allow members to read: dav plugin gives access to all project data.
-        """
+        # Todo: Pull various bits of access controller setup together under the name 'setupAccessControl'.
         super(Plugin, self).onCreate()
-        findObject = FindProtectionObject(self.domainObject)
-        protectionObject = findObject.find()
-        read = protectionObject.permissions[self.registry.actions['Read']]
+        protectionObject = FindProtectionObject(self.domainObject).find()
+        # Don't allow Friends to read the DAV plugin, as it gives access to all project data.
+        permission = protectionObject.permissions[self.registry.actions['Read']]
         friend = self.registry.roles['Friend']
-        if read in friend.grants:
-            grant = friend.grants[read]
+        if permission in friend.grants:
+            grant = friend.grants[permission]
+            grant.delete()
+        # Don't allow Developers to write to the DAV plugin, as it gives access to all project data.
+        permission = protectionObject.permissions[self.registry.actions['Update']]
+        friend = self.registry.roles['Developer']
+        if permission in friend.grants:
+            grant = friend.grants[permission]
             grant.delete()
 
