@@ -1,5 +1,3 @@
-import pkg_resources
-
 import dm.plugin.factory
 
 # TODO: appears that this is only used from dom.plugin.Plugin.getSystem()
@@ -17,14 +15,24 @@ class PluginFactory(dm.plugin.factory.PluginFactory):
             try:
                 entrypoint = self.getEntryPoint(name)
             except MissingPluginEntryPoint, inst:
-                msg = "Could not find plugin class either in plugin directory"
-                msg += " or in otherwise defined location within a setuptools"
-                msg += " entry point: %s" % str(inst)
-                raise Excpetion, msg
-            pluginClass = entrypoint.load()
+                msg = "Could not find a setuptools entry point"
+                msg += " for '%s' plugin: %s" % (name, str(inst))
+                self.logger.warn(msg)
+                pluginClass = None
+            else:
+                try:
+                    pluginClass = entrypoint.load()
+                except Exception, inst:
+                    msg = "Could not load setuptools entry point"
+                    msg += " for '%s' plugin." % name # No point using the inst
+                    # string because it is misleading (refers to Django).
+                    #msg += " for '%s' plugin: %s" % (name, str(inst))
+                    self.logger.error(msg)
+                    pluginClass = None
         return pluginClass
 
     def getEntryPoint(self, name):
+        import pkg_resources
         for entrypoint in pkg_resources.iter_entry_points('kforge.plugins'):
             if entrypoint.name == name:
                 return entrypoint
@@ -32,6 +40,7 @@ class PluginFactory(dm.plugin.factory.PluginFactory):
         raise MissingPluginEntryPoint(msg)
 
     def getEntryPoints(self):
+        import pkg_resources
         entrypoints = []
         for en in pkg_resources.iter_entry_points('kforge.plugins'):
             entrypoints.append(en)
