@@ -46,15 +46,15 @@ class Plugin(kforge.plugin.base.ServicePlugin):
         self.moinUtils = MoinUtils(self.dictionary['moin.system_path'])
     
     def onServiceCreate(self, service):
-        if service and service.plugin and service.plugin.name == 'moin':
-            self.ensureProjectPluginDirectoryExists(service)
+        if self.isOurs(service):
+            self.assertServicesFolder(service)
             wikiPath = service.getDirPath()
             self.moinUtils.createWiki(wikiPath)
     
-    def onServicePurge(self, service):
-        if service and service.plugin and service.plugin.name == 'moin':
-            wikiPath = service.getDirPath()
-            self.moinUtils.deleteWiki(wikiPath)
+    #def onServicePurge(self, service):
+    #    if self.isOurs(service):
+    #        wikiPath = service.getDirPath()
+    #        self.moinUtils.deleteWiki(wikiPath)
     
     def getApacheConfigCommon(self):
         """
@@ -111,7 +111,7 @@ class MoinUtils(object):
         [[TODO: allow for fastcgi]]
         """
         if self.wikiExists(wikiName):
-            raise('Cannot create wiki as path already exists: %s' % self.getWikiPath(wikiName))
+            raise Exception('Cannot create wiki as path already exists: %s' % self.getWikiPath(wikiName))
         newWikiBasePath = self.getWikiPath(wikiName)
         self.logger.info('Creating new wiki: %s' % newWikiBasePath)
         os.makedirs(newWikiBasePath)
