@@ -1,28 +1,22 @@
-"""
-KForge svn (Subversion) plugin.
+"""KForge Subversion Plugin
 
-Enabling this plugin allows users to create Subversion services to provide
-Subversion repositories for their project.
+Enabling this plugin allows KForge project administrators to create Subversion version control system services.
 
-## Installation ##
+Creating services with this plugin requires:
 
-1. Dependencies. To create services using this plugin you must have installed
-   the following external applications:
+  * Subversion. The 'svnadmin' command is used to create repositories.
 
-   * Subversion
-   * Apache modules to provide access to Subversion through Apache (e.g. on
-     debian the libapache2-svn package must be installed and the associated
-     modules enabled).
+Providing access to this plugin's services requires:
 
-2. KForge config file. You do not need to add anything to the KForge config
-   file.
+  * Apache. The mod_python, mod_dav, mod_dav_fs, and mod_dav_svn Apache modules are used to provide access to Subversion through Apache. For example, on Debian the libapache2-mod-python and libapache2-svn packages must be installed and enabled.
 
-3. Install and enable this plugin in the usual way (see the KForge
-   Documentation for details).
+You do not need to add anything to the KForge config file.
 
- $ kforge-admin plugin enable svn
- $ kforge-admin plugin disable svn
+You can enable, disable, and show status in the usual way.
 
+  $ kforge-admin plugin enable svn
+  $ kforge-admin plugin show svn
+  $ kforge-admin plugin disable svn
 """
 import os
 import commands
@@ -30,6 +24,7 @@ import shutil
 
 import kforge.plugin.base
 import kforge.utils.backup
+from kforge.dictionary import SVN_ADMIN_SCRIPT
 
 class Plugin(kforge.plugin.base.ServicePlugin):
     "Subversion plugin."
@@ -37,45 +32,38 @@ class Plugin(kforge.plugin.base.ServicePlugin):
     def __init__(self, domainObject):
         super(Plugin, self).__init__(domainObject)
         self.utils = SvnUtils()
-    
-    def onServiceCreate(self, service):
-        if service and service.plugin and service.plugin.name == 'svn':
-            self.ensureProjectPluginDirectoryExists(service)
-            msg = 'SvnPlugin: Creating %s service stuff...' % (
-                service
-            )
-            self.log(msg)
-            path = service.getDirPath()
-            self.assertNotFileForPath(path)
-            self.utils.createRepository(path)
-            self.assertFileForPath(path)
-            msg = 'SvnPlugin: Created %s service stuff on path: %s)' % (
-                service, path
-            )
-            self.log(msg)
-    
-    def onServicePurge(self, service):
-        if service and service.plugin and service.plugin.name == 'svn':
-            path = service.getDirPath()
-            self.utils.deleteRepository(path)
-            self.assertNotFileForPath(path)
-            msg = 'SvnPlugin: Deleted service %s on path: %s' % (
-                service, path
-            )
-            self.log(msg)
-            
-    def assertNotFileForPath(self, path):
-        if os.path.exists(path):
-            message = "Subversion repository exists on path: %s" % path
-            self.logger.error(message)
-            raise message
-
-    def assertFileForPath(self, path):
-        if not os.path.exists(path):
-            message = "Subversion repository doesn't exist on path %s" % path
-            self.logger.error(message)
-            raise message
    
+    def checkDependencies(self):
+        errors = []
+        svnadminPath = self.dictionary[SVN_ADMIN_SCRIPT]
+        cmd = 'which %s' % svnadminPath
+        (status, output) = commands.getstatusoutput(cmd) 
+        if status:
+            errors.append("Couldn't find Subversion admin script '%s' on path." % svnadminPath)
+        return errors
+
+    def showDepends(self):
+        svnadminPath = self.dictionary[SVN_ADMIN_SCRIPT]
+        cmd = 'which %s' % svnadminPath
+        (status, output) = commands.getstatusoutput(cmd) 
+        return [
+            "Subversion admin: %s" % (status and "Not found!" or ("Found OK. %s" % output)),
+            "Apache dav module: %s" % "Please check this module is enabled.",
+            "Apache dav_fs module: %s" % "Please check this module is enabled.",
+            "Apache dav_svn module: %s" % "Please check this module is enabled.",
+        ]
+    showDepends = classmethod(showDepends)
+ 
+    def onServiceCreate(self, service):
+        if self.isOurs(service):
+            servicePath = self.paths.getServicePath(service)
+            msg = 'SvnPlugin: Creating new Subversion repository for %s: %s' % (
+                service, servicePath
+            )
+            self.logger.info(msg)
+            self.paths.assertServiceFolder(service)
+            self.utils.createRepository(servicePath)
+    
     def getApacheConfig(self, service):
         config = """
         <Location %(urlPath)s>
@@ -100,9 +88,8 @@ class Plugin(kforge.plugin.base.ServicePlugin):
 <p>Note that if you wish to 'commit' work to the repository you must have a role on the project that includes 'write' permissions on Subversion services.</p>
 '''
 
-    def getUserHelp(self, service):
-        serviceUrl = service.getUrl()
-        values = { 'url' : serviceUrl }
+    def getUserHelp(self, service, serviceLocation):
+        values = { 'url' : serviceLocation }
         msg = self.helpMessage % values
         return msg
     
@@ -113,6 +100,7 @@ class Plugin(kforge.plugin.base.ServicePlugin):
         )
         backupItem.doBackup()
 
+
 class SvnUtils(object):
     
     def __init__(self, parentPath = ''):
@@ -121,9 +109,12 @@ class SvnUtils(object):
                      repositories. If not defined then defaults to empty string
                      (so repositories must be specified with their path)
         """
-        self.parentPath = parentPath
+        # NB: Only used in svntest.py.
+        # Todo: Move test path switching to dictionary manipulations?
+        self.parentPath = parentPath  
    
-    # todo: remove this function: only used when parentPath != '' in test
+    # NB: Only used when parentPath != '' in test.
+    # Todo: Remove this function, it's distracting. :-)
     def getRepositoryPath(self, name):
         "Returns file system path from repository name."
         path = os.path.join(self.parentPath, name)
@@ -136,16 +127,12 @@ class SvnUtils(object):
                its own and if relative it is joined to parentPath defined at
                creation of class.
         """
-        fullPath = self.getRepositoryPath(path)
-        # cheap way to ensure parent directories exist (svn doesn't mind if
-        # target directory exists as long as non-empty)
-        if not os.path.exists(fullPath):
-            os.makedirs(fullPath)
+        path = self.getRepositoryPath(path)
         type = 'fsfs'
-        cmd = 'svnadmin create %s --fs-type %s' % (fullPath, type)
+        cmd = 'svnadmin create %s --fs-type %s' % (path, type)
         status, output = commands.getstatusoutput(cmd)
         if status:
-            raise Exception('svnadmin create error on %s: %s' % (cmd, output))
+            raise Exception('Subversion command error: %s: %s' % (cmd, output))
 
     def deleteRepository(self, path):
         """
