@@ -29,14 +29,9 @@ class Plugin(kforge.plugin.base.SingleServicePlugin):
         For www since a single service plugin only want the plugin directory
         and do not need a service subdirectory
         """
-        if service and service.plugin and service.plugin.name == self.domainObject.name:
-            self.ensureProjectPluginDirectoryExists(service)
-    
-    def onServicePurge(self, service):
-        if service and service.plugin and service.plugin.name == self.domainObject.name:
-            projectPluginPath = self.paths.getProjectPluginPath(service.project, service.plugin)
-            if os.path.exists(projectPluginPath):
-                shutil.rmtree(projectPluginPath)
+        if self.isOurs(service):
+            path = self.paths.getProjectPluginPath(service.project, service.plugin)
+            self.paths.assertFolder(path, 'project services')
     
     def getApacheConfig(self, service):
         """
