@@ -13,13 +13,12 @@ class UrlSchemeTest(TestCase):
     prefix = ''
 
     def setUp(self):
-        self.dictionary = kforge.ioc.RequiredFeature('SystemDictionary')
-        self.current_prefix = self.dictionary['www.uri_prefix']
-        self.dictionary.set('www.uri_prefix', self.prefix)
+        self.current_prefix = self.dictionary[self.dictionary.words.URI_PREFIX]
+        self.dictionary[self.dictionary.words.URI_PREFIX] = self.prefix
         self.scheme = kforge.url.UrlScheme()
 
     def tearDown(self):
-        self.dictionary.set('www.uri_prefix', self.current_prefix)
+        self.dictionary[self.dictionary.words.URI_PREFIX] = self.current_prefix
 
     def _path(self, path):
         return self.prefix + path
