@@ -10,6 +10,9 @@ import kforge.utils.upgrade
 import kforge.utils.admin
 
 class UpgradeDbTo0Point13Test(unittest.TestCase):
+    tags = [ 'cli' ]
+    disable = True
+
     oldSql = '~/svnroot/kforge/misc/knowledgeforge-kforge-0.12.sql'
 
     def setUp(self):
@@ -22,6 +25,8 @@ class UpgradeDbTo0Point13Test(unittest.TestCase):
         self.cmd.execute()
 
 class UpgradeDataTo0Point11Test(unittest.TestCase):
+    tags = [ 'cli' ]
+    disable = True
     
     def setUp(self):
         self.tmpDir = tempfile.mkdtemp()
@@ -43,6 +48,8 @@ class UpgradeDbTo0Point10Test(unittest.TestCase):
     For test to work you need to provide a db dump of a 0.9 db and provide link
     to it below and also edit the other values to reflect your setup.
     """
+    tags = [ 'cli' ]
+    disable = True
     
     oldSql = os.path.normpath('~/db_dumps/kforge_0.9.sql')
     # edit these values to reflect the state of your original install
@@ -86,6 +93,8 @@ class UpgradeDbTo0Point10Test(unittest.TestCase):
 
 
 class UpgradeDbTo0Point11Test(UpgradeDbTo0Point10Test):
+    tags = [ 'cli' ]
+    disable = True
     
     oldSql = os.path.normpath('~/db_dumps/kforge_0.10.sql')
     numberOfUsers = 36
